@@ -1,5 +1,6 @@
 # Copyright 2020 Michael Still
 
+from functools import partial
 import ipaddress
 import os
 import psutil
@@ -9,11 +10,15 @@ from uuid import uuid4
 
 
 from shakenfist import baseobject
+from shakenfist.baseobject import (
+    DatabaseBackedObject as dbo,
+    DatabaseBackedObjectIterator as dbo_iter)
 from shakenfist.config import config
 from shakenfist import db
 from shakenfist import dhcp
 from shakenfist import etcd
 from shakenfist.exceptions import DeadNetwork
+from shakenfist import instance
 from shakenfist.ipmanager import IPManager
 from shakenfist import logutil
 from shakenfist import networkinterface
@@ -24,21 +29,20 @@ from shakenfist.tasks import (
     RemoveDHCPNetworkTask,
     RemoveNATNetworkTask)
 from shakenfist import util
-from shakenfist import virt
 
 
 LOG, _ = logutil.setup(__name__)
 
 
-class Network(baseobject.DatabaseBackedObject):
+class Network(dbo):
     object_type = 'network'
     current_version = 2
     state_targets = {
-        None: ('initial', ),
-        'initial': ('created', 'deleted', 'error'),
-        'created': ('created', 'deleted', 'error'),
-        'error': ('deleted', 'error'),
-        'deleted': (),
+        None: (dbo.STATE_INITIAL, ),
+        dbo.STATE_INITIAL: (dbo.STATE_CREATED, dbo.STATE_DELETED, dbo.STATE_ERROR),
+        dbo.STATE_CREATED: (dbo.STATE_DELETED, dbo.STATE_ERROR),
+        dbo.STATE_ERROR: (dbo.STATE_DELETED, dbo.STATE_ERROR),
+        dbo.STATE_DELETED: (),
     }
 
     def __init__(self, static_values):
@@ -52,8 +56,10 @@ class Network(baseobject.DatabaseBackedObject):
         self.__provide_nat = static_values.get('provide_nat')
         self.__vxid = static_values.get('vxid')
 
-        self.physical_nic = static_values.get(
-            'physical_nic', config.get('NODE_EGRESS_NIC'))
+        self.egress_nic = static_values.get(
+            'egress_nic', config.NODE_EGRESS_NIC)
+        self.mesh_nic = static_values.get(
+            'mesh_nic', config.NODE_MESH_NIC)
 
         ipm = IPManager.from_db(self.uuid)
         self.__ipblock = ipm.network_address
@@ -102,7 +108,7 @@ class Network(baseobject.DatabaseBackedObject):
         )
 
         n = Network.from_db(uuid)
-        n.state = 'initial'
+        n.state = Network.STATE_INITIAL
         n.add_event('db record creation', None)
 
         # Networks should immediately appear on the network node
@@ -245,10 +251,10 @@ class Network(baseobject.DatabaseBackedObject):
             'vx_veth_outer': 'veth-%06x-o' % self.vxid,
             'vx_veth_inner': 'veth-%06x-i' % self.vxid,
 
-            'physical_interface': self.physical_nic,
-            'physical_bridge': 'phy-br-%s' % config.get('NODE_EGRESS_NIC'),
-            'physical_veth_outer': 'phy-%06x-o' % self.vxid,
-            'physical_veth_inner': 'phy-%06x-i' % self.vxid,
+            'egress_bridge': 'egr-br-%s' % config.NODE_EGRESS_NIC,
+            'egress_veth_outer': 'egr-%06x-o' % self.vxid,
+            'egress_veth_inner': 'egr-%06x-i' % self.vxid,
+            'mesh_interface': self.mesh_nic,
 
             'netns': self.uuid,
             'in_netns': 'ip netns exec %s' % self.uuid,
@@ -290,7 +296,7 @@ class Network(baseobject.DatabaseBackedObject):
         callers will wait on a lock before calling this function. In this case
         we definitely need to update the in-memory object model.
         """
-        return self.state.value in ('deleted', 'error')
+        return self.state.value in (self.STATE_DELETED, self.STATE_ERROR)
 
     def _create_common(self):
         subst = self.subst_dict()
@@ -299,7 +305,7 @@ class Network(baseobject.DatabaseBackedObject):
             with util.RecordedOperation('create vxlan interface', self):
                 util.create_interface(
                     subst['vx_interface'], 'vxlan',
-                    'id %(vx_id)s dev %(physical_interface)s dstport 0'
+                    'id %(vx_id)s dev %(mesh_interface)s dstport 0'
                     % subst)
                 util.execute(None, 'sysctl -w net.ipv4.conf.'
                                    '%(vx_interface)s.arp_notify=1' % subst)
@@ -360,19 +366,19 @@ class Network(baseobject.DatabaseBackedObject):
                         '%(in_netns)s ip addr add %(router)s/%(netmask)s '
                         'dev %(vx_veth_inner)s' % subst)
 
-            if not util.check_for_interface(subst['physical_veth_outer']):
-                with util.RecordedOperation('create physical veth', self):
+            if not util.check_for_interface(subst['egress_veth_outer']):
+                with util.RecordedOperation('create egress veth', self):
                     util.create_interface(
-                        subst['physical_veth_outer'], 'veth',
-                        'peer name %(physical_veth_inner)s' % subst)
+                        subst['egress_veth_outer'], 'veth',
+                        'peer name %(egress_veth_inner)s' % subst)
                     util.execute(None,
-                                 'brctl addif %(physical_bridge)s '
-                                 '%(physical_veth_outer)s' % subst)
+                                 'brctl addif %(egress_bridge)s '
+                                 '%(egress_veth_outer)s' % subst)
                     util.execute(None,
-                                 'ip link set %(physical_veth_outer)s up'
+                                 'ip link set %(egress_veth_outer)s up'
                                  % subst)
                     util.execute(None,
-                                 'ip link set %(physical_veth_inner)s '
+                                 'ip link set %(egress_veth_inner)s '
                                  'netns %(netns)s' % subst)
 
             if self.provide_nat:
@@ -384,7 +390,7 @@ class Network(baseobject.DatabaseBackedObject):
                     ipm = IPManager.from_db('floating')
                     if not self.floating_gateway:
                         self.update_floating_gateway(
-                            ipm.get_random_free_address())
+                            ipm.get_random_free_address(self.unique_label()))
                         ipm.persist()
 
                     subst['floating_router'] = ipm.get_address_at_index(1)
@@ -394,15 +400,15 @@ class Network(baseobject.DatabaseBackedObject):
                 with util.RecordedOperation('enable virtual routing', self):
                     addresses = util.get_interface_addresses(
                         subst['netns'],
-                        subst['physical_veth_inner'])
+                        subst['egress_veth_inner'])
                     if not subst['floating_gateway'] in list(addresses):
                         util.execute(None,
                                      '%(in_netns)s ip addr add '
                                      '%(floating_gateway)s/%(floating_netmask)s '
-                                     'dev %(physical_veth_inner)s' % subst)
+                                     'dev %(egress_veth_inner)s' % subst)
                         util.execute(None,
                                      '%(in_netns)s ip link set '
-                                     '%(physical_veth_inner)s up' % subst)
+                                     '%(egress_veth_inner)s up' % subst)
 
                     default_routes = util.get_default_routes(subst['netns'])
                     if default_routes != [subst['floating_router']]:
@@ -419,14 +425,50 @@ class Network(baseobject.DatabaseBackedObject):
                 self.enable_nat()
 
         self.update_dhcp()
+        self.state = self.STATE_CREATED
 
-    def delete(self):
+    def delete_on_hypervisor(self):
         with self.get_lock(op='Network delete'):
-            if self.is_dead():
-                self.log.info('Network died whilst waiting for lock')
-                return
-            self._delete_on_node()
-            self.state = 'deleted'
+            subst = self.subst_dict()
+
+            if util.check_for_interface(subst['vx_bridge']):
+                with util.RecordedOperation('delete vxlan bridge', self):
+                    util.execute(None, 'ip link delete %(vx_bridge)s' % subst)
+
+            if util.check_for_interface(subst['vx_interface']):
+                with util.RecordedOperation('delete vxlan interface', self):
+                    util.execute(
+                        None, 'ip link delete %(vx_interface)s' % subst)
+
+    def delete_on_network_node(self):
+        with self.get_lock(op='Network delete'):
+            subst = self.subst_dict()
+
+            if util.is_network_node():
+                if util.check_for_interface(subst['vx_veth_outer']):
+                    with util.RecordedOperation('delete router veth', self):
+                        util.execute(
+                            None, 'ip link delete %(vx_veth_outer)s' % subst)
+
+                if util.check_for_interface(subst['egress_veth_outer']):
+                    with util.RecordedOperation('delete egress veth', self):
+                        util.execute(
+                            None,
+                            'ip link delete %(egress_veth_outer)s' % subst)
+
+                if os.path.exists('/var/run/netns/%(netns)s' % subst):
+                    with util.RecordedOperation('delete netns', self):
+                        util.execute(None, 'ip netns del %(netns)s' % subst)
+
+                if self.floating_gateway:
+                    with db.get_lock('ipmanager', None, 'floating', ttl=120,
+                                     op='Network delete'):
+                        ipm = IPManager.from_db('floating')
+                        ipm.release(self.floating_gateway)
+                        ipm.persist()
+                        self.update_floating_gateway(None)
+
+            self.state = self.STATE_DELETED
 
         self.remove_dhcp()
         self.remove_nat()
@@ -434,57 +476,9 @@ class Network(baseobject.DatabaseBackedObject):
         ipm = IPManager.from_db(self.uuid)
         ipm.delete()
 
-    def delete_on_node_with_lock(self):
-        with self.get_lock(op='Network delete on node'):
-            if self.is_dead():
-                self.log.info('Network died whilst waiting for lock')
-                return
-            self._delete_on_node()
-
-    def _delete_on_node(self):
-        subst = self.subst_dict()
-        LOG.with_fields(subst).debug('net.delete_on_node()')
-
-        # Cleanup local node
-        if util.check_for_interface(subst['vx_bridge']):
-            with util.RecordedOperation('delete vxlan bridge', self):
-                util.execute(None, 'ip link delete %(vx_bridge)s' % subst)
-
-        if util.check_for_interface(subst['vx_interface']):
-            with util.RecordedOperation('delete vxlan interface', self):
-                util.execute(
-                    None, 'ip link delete %(vx_interface)s' % subst)
-
-        # If this is the network node do additional cleanup
-        if util.is_network_node():
-            if util.check_for_interface(subst['vx_veth_outer']):
-                with util.RecordedOperation('delete router veth', self):
-                    util.execute(
-                        None, 'ip link delete %(vx_veth_outer)s' % subst)
-
-            if util.check_for_interface(subst['physical_veth_outer']):
-                with util.RecordedOperation('delete physical veth', self):
-                    util.execute(
-                        None,
-                        'ip link delete %(physical_veth_outer)s' % subst)
-
-            if os.path.exists('/var/run/netns/%(netns)s' % subst):
-                with util.RecordedOperation('delete netns', self):
-                    util.execute(None, 'ip netns del %(netns)s' % subst)
-
-            if self.floating_gateway:
-                with db.get_lock('ipmanager', None, 'floating', ttl=120,
-                                 op='Network delete'):
-                    ipm = IPManager.from_db('floating')
-                    ipm.release(self.floating_gateway)
-                    ipm.persist()
-                    self.update_floating_gateway(None)
-
-        Network.deallocate_vxid(self.vxid)
-        IPManager.from_db(self.uuid).delete()
-
     def hard_delete(self):
         etcd.delete('network', None, self.uuid)
+        etcd.delete('vxid', None, self.vxid)
         etcd.delete_all('attribute/network', self.uuid)
         etcd.delete_all('event/network', self.uuid)
         db.delete_metadata('network', self.uuid)
@@ -536,25 +530,27 @@ class Network(baseobject.DatabaseBackedObject):
                              'echo 1 > /proc/sys/net/ipv4/ip_forward')
                 util.execute(None,
                              '%(in_netns)s iptables -A FORWARD '
-                             '-o %(physical_veth_inner)s '
+                             '-o %(egress_veth_inner)s '
                              '-i %(vx_veth_inner)s -j ACCEPT' % subst)
                 util.execute(None,
                              '%(in_netns)s iptables -A FORWARD '
-                             '-i %(physical_veth_inner)s '
+                             '-i %(egress_veth_inner)s '
                              '-o %(vx_veth_inner)s -j ACCEPT' % subst)
                 util.execute(None,
                              '%(in_netns)s iptables -t nat -A POSTROUTING '
                              '-s %(ipblock)s/%(netmask)s '
-                             '-o %(physical_veth_inner)s '
+                             '-o %(egress_veth_inner)s '
                              '-j MASQUERADE' % subst)
 
     def remove_nat(self):
         if util.is_network_node():
             if self.floating_gateway:
-                ipm = IPManager.from_db('floating')
-                ipm.release(self.floating_gateway)
-                ipm.persist()
-                self.update_floating_gateway(None)
+                with db.get_lock('ipmanager', None, 'floating', ttl=120,
+                                 op='Remove NAT'):
+                    ipm = IPManager.from_db('floating')
+                    ipm.release(self.floating_gateway)
+                    ipm.persist()
+                    self.update_floating_gateway(None)
 
         else:
             db.enqueue('networknode', RemoveNATNetworkTask(self.uuid))
@@ -587,7 +583,7 @@ class Network(baseobject.DatabaseBackedObject):
 
             node_fqdns = []
             for inst_uuid in instances:
-                inst = virt.Instance.from_db(inst_uuid)
+                inst = instance.Instance.from_db(inst_uuid)
                 placement = inst.placement
                 if not placement:
                     continue
@@ -599,11 +595,13 @@ class Network(baseobject.DatabaseBackedObject):
 
             # NOTE(mikal): why not use DNS here? Well, DNS might be outside
             # the control of the deployer if we're running in a public cloud
-            # as an overlay cloud...
+            # as an overlay cloud... Also, we don't include ourselves in the
+            # mesh as that would cause duplicate packets to reflect back to us.
+            # (see bug #859).
             node_ips = set([config.NETWORK_NODE_IP])
             for fqdn in node_fqdns:
                 n = Node.from_db(fqdn)
-                if n:
+                if n and n.ip != config.NODE_MESH_IP:
                     node_ips.add(n.ip)
 
             discovered = list(self.discover_mesh())
@@ -690,7 +688,7 @@ class Network(baseobject.DatabaseBackedObject):
                          % subst)
 
 
-class Networks(baseobject.DatabaseBackedObjectIterator):
+class Networks(dbo_iter):
     def __iter__(self):
         for _, n in etcd.get_all('network', None):
             if n['uuid'] == 'floating':
@@ -703,3 +701,15 @@ class Networks(baseobject.DatabaseBackedObjectIterator):
             out = self.apply_filters(n)
             if out:
                 yield out
+
+
+# Convenience helpers
+
+def inactive_networks():
+    return Networks([
+                    baseobject.inactive_states_filter,
+                    partial(baseobject.state_age_filter, config.CLEANER_DELAY)])
+
+
+def networks_in_namespace(namespace):
+    return Networks([partial(baseobject.namespace_filter, namespace)])
