@@ -8,7 +8,7 @@ from pydantic import AnyHttpUrl, IPvAnyAddress
 
 from shakenfist import dhcp
 from shakenfist.ipmanager import IPManager
-from shakenfist.config import SFConfigBase
+from shakenfist.config import BaseSettings
 
 TEST_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -39,7 +39,7 @@ class DHCPTestCase(testtools.TestCase):
     def setUp(self):
         super(DHCPTestCase, self).setUp()
 
-        class FakeConfig(SFConfigBase):
+        class FakeConfig(BaseSettings):
             DNS_SERVER: str = '8.8.8.8'
             MAX_HYPERVISOR_MTU: int = 8000
             NODE_NAME: str = 'foo'
@@ -48,7 +48,7 @@ class DHCPTestCase(testtools.TestCase):
             ETCD_USER: str = 'sf'
             ETCD_PASSWORD: str = 'foo'
             ETCD_SERVER: str = 'localhost'
-            NODE_IP: IPvAnyAddress = '127.0.0.1'
+            NODE_EGRESS_IP: IPvAnyAddress = '127.0.0.1'
             DOWNLOAD_URL_CIRROS: AnyHttpUrl = ('http://download.cirros-cloud.net/%(vernum)s/'
                                                'cirros-%(vernum)s-x86_64-disk.img')
 
@@ -142,7 +142,7 @@ class DHCPTestCase(testtools.TestCase):
                                           'ipv4': '127.0.0.6',
                                           'order': 0})
                 ])
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 side_effect=[
                     {'uuid': 'instuuid1',
                      'name': 'inst1',
