@@ -4,8 +4,10 @@ import json
 import mock
 
 
-from shakenfist.baseobject import State
-from shakenfist.config import config, SFConfigBase, SFConfig
+from shakenfist.baseobject import (
+    DatabaseBackedObject as dbo,
+    State)
+from shakenfist.config import config, BaseSettings, SFConfig
 from shakenfist.external_api import app as external_api
 from shakenfist.ipmanager import IPManager
 from shakenfist.tests import test_shakenfist
@@ -56,7 +58,7 @@ class FakeInstance(BaseFakeObject):
     object_type = 'instance'
 
     def __init__(self, uuid=None, namespace=None,
-                 state='created', power_state='on',
+                 state=dbo.STATE_CREATED, power_state='on',
                  placement='node1'):
         super(FakeInstance, self).__init__(state)
 
@@ -71,7 +73,7 @@ class FakeNetwork(BaseFakeObject):
     object_type = 'network'
 
     def __init__(self, uuid=None, vxid=None, namespace=None,
-                 name=None, netblock=None, state='created'):
+                 name=None, netblock=None, state=dbo.STATE_CREATED):
         super(FakeNetwork, self).__init__(state)
         self.uuid = uuid
         self.vxid = vxid
@@ -263,7 +265,7 @@ class ExternalApiTestCase(test_shakenfist.ShakenFistTestCase):
             NODE_NAME='node1',
         )
 
-        self.config = mock.patch('shakenfist.virt.config',
+        self.config = mock.patch('shakenfist.instance.config',
                                  fake_config)
         self.mock_config = self.config.start()
         self.addCleanup(self.config.stop)
@@ -388,9 +390,9 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
             },
             resp.get_json())
 
-    @mock.patch('shakenfist.virt.Instance._db_get_attribute',
-                return_value={'value': 'created', 'update_time': 2})
-    @mock.patch('shakenfist.virt.Instances',
+    @mock.patch('shakenfist.instance.Instance._db_get_attribute',
+                return_value={'value': dbo.STATE_CREATED, 'update_time': 2})
+    @mock.patch('shakenfist.instance.Instances',
                 return_value=[FakeInstance(uuid='123')])
     def test_delete_namespace_with_instances(self, mock_get_instances,
                                              mock_get_instance_attribute):
@@ -404,9 +406,9 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
             },
             resp.get_json())
 
-    @mock.patch('shakenfist.virt.Instances', return_value=[])
+    @mock.patch('shakenfist.instance.Instances', return_value=[])
     @mock.patch('shakenfist.net.Networks',
-                return_value=[FakeNetwork(uuid='123', state='created')])
+                return_value=[FakeNetwork(uuid='123', state=dbo.STATE_CREATED)])
     def test_delete_namespace_with_networks(self, mock_get_networks, mock_get_instances):
         resp = self.client.delete('/auth/namespaces/foo',
                                   headers={'Authorization': self.auth_header})
@@ -517,40 +519,49 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
                          resp.get_json())
         self.assertEqual(404, resp.status_code)
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
-                return_value={'uuid': '123',
-                              'cpus': 2,
-                              'memory': 4096,
-                              'name': 'banana',
-                              'namespace': 'foo',
-                              'disk_spec': [{'size': 4, 'base': 'foo'}]})
-    @mock.patch('shakenfist.virt.Instance._db_get_attribute',
+    @mock.patch('shakenfist.instance.Instance._db_get',
+                return_value={
+                    'cpus': 1,
+                    'disk_spec': [{}],
+                    'memory': 2048,
+                    'name': 'barry',
+                    'namespace': 'namespace',
+                    'requested_placement': None,
+                    'ssh_key': 'sshkey',
+                    'user_data': 'userdata',
+                    'uuid': 'uuid42',
+                    'version': 3,
+                    'video': {'memory': 16384, 'model': 'cirrus'},
+                    'uefi': False
+                })
+    @mock.patch('shakenfist.instance.Instance._db_get_attribute',
                 return_value={})
     def test_get_instance(self, mock_get_instance_attribute, mock_get_instance):
         resp = self.client.get(
             '/instances/foo', headers={'Authorization': self.auth_header})
         self.assertEqual({
             'console_port': None,
-            'cpus': 2,
-            'disk_spec': [{'base': 'foo', 'size': 4}],
+            'cpus': 1,
+            'disk_spec': [{}],
             'error_message': None,
-            'memory': 4096,
-            'name': 'banana',
-            'namespace': 'foo',
+            'memory': 2048,
+            'name': 'barry',
+            'namespace': 'namespace',
             'node': None,
             'power_state': None,
-            'ssh_key': None,
+            'ssh_key': 'sshkey',
             'state': None,
-            'user_data': None,
-            'uuid': '123',
-            'version': None,
+            'uefi': False,
+            'user_data': 'userdata',
+            'uuid': 'uuid42',
             'vdi_port': None,
-            'video': None
+            'version': 3,
+            'video': {'memory': 16384, 'model': 'cirrus'}
         }, resp.get_json())
         self.assertEqual(200, resp.status_code)
         self.assertEqual('application/json', resp.content_type)
 
-    @mock.patch('shakenfist.virt.Instance._db_get', return_value=None)
+    @mock.patch('shakenfist.instance.Instance._db_get', return_value=None)
     def test_get_instance_not_found(self, mock_get_instance):
         resp = self.client.get(
             '/instances/foo', headers={'Authorization': self.auth_header})
@@ -559,7 +570,7 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         self.assertEqual(404, resp.status_code)
         self.assertEqual('application/json', resp.content_type)
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 return_value={'uuid': 'foo',
                               'name': 'banana',
                               'namespace': 'foo',
@@ -572,7 +583,7 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         self.assertEqual('application/json', resp.content_type)
         self.assertEqual(200, resp.status_code)
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 return_value={'uuid': 'foo',
                               'name': 'banana',
                               'namespace': 'foo',
@@ -592,7 +603,7 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         self.assertEqual(200, resp.status_code)
         mock_md_put.assert_called_with('instance', 'foo', {'foo': 'bar'})
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 return_value={'uuid': 'foo',
                               'name': 'banana',
                               'namespace': 'foo',
@@ -665,7 +676,7 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         self.assertEqual(200, resp.status_code)
         mock_md_put.assert_called_with('network', 'foo', {'foo': 'bar'})
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 return_value={'uuid': 'foo',
                               'name': 'banana',
                               'namespace': 'foo',
@@ -681,7 +692,7 @@ class ExternalApiGeneralTestCase(ExternalApiTestCase):
         mock_md_put.assert_called_with('instance', 'foo', {'real': 'smart'})
         self.assertEqual(200, resp.status_code)
 
-    @mock.patch('shakenfist.virt.Instance._db_get',
+    @mock.patch('shakenfist.instance.Instance._db_get',
                 return_value={'uuid': 'foo',
                               'name': 'banana',
                               'namespace': 'foo',
@@ -739,12 +750,12 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         def fake_virt_from_db(uuid):
             return {'uuid': uuid}
 
-        self.virt_from_db = mock.patch('shakenfist.virt.Instance.from_db',
+        self.virt_from_db = mock.patch('shakenfist.instance.Instance.from_db',
                                        fake_virt_from_db)
         self.mock_virt_from_db = self.virt_from_db.start()
         self.addCleanup(self.virt_from_db.stop)
 
-        class FakeConfig(SFConfigBase):
+        class FakeConfig(BaseSettings):
             API_ASYNC_WAIT: int = 1
             LOG_METHOD_TRACE: int = 1
 
@@ -756,16 +767,16 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         self.addCleanup(self.config.stop)
 
     @mock.patch('shakenfist.db.enqueue')
-    @mock.patch('shakenfist.virt.Instances',
+    @mock.patch('shakenfist.instance.Instances',
                 return_value=[
                     FakeInstance(
                         namespace='system',
                         uuid='6a973b82-31b3-4780-93e4-04d99ae49f3f',
-                        state=['created']),
+                        state=[dbo.STATE_CREATED]),
                     FakeInstance(
                         namespace='system',
                         uuid='847b0327-9b17-4148-b4ed-be72b6722c17',
-                        state=['created'])])
+                        state=[dbo.STATE_CREATED])])
     @mock.patch('shakenfist.etcd.put')
     @mock.patch('shakenfist.db.get_lock')
     def test_delete_all_instances(
@@ -787,7 +798,7 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         resp = self.client.post('/instances',
                                 headers={'Authorization': self.auth_header},
                                 data=json.dumps({
-                                    'name': 'test_instance',
+                                    'name': 'test-instance',
                                     'cpus': 1,
                                     'memory': 1024,
                                     'network': [],
@@ -806,7 +817,7 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
         resp = self.client.post('/instances',
                                 headers={'Authorization': self.auth_header},
                                 data=json.dumps({
-                                    'name': 'test_instance',
+                                    'name': 'test-instance',
                                     'cpus': 1,
                                     'memory': 1024,
                                     'network': [],
@@ -821,11 +832,12 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
             resp.get_json())
         self.assertEqual(400, resp.status_code)
 
-    def test_post_instance_invalid_network(self):
+    @mock.patch('shakenfist.artifact.Artifact.from_url')
+    def test_post_instance_invalid_network(self, mock_get_artifact):
         resp = self.client.post('/instances',
                                 headers={'Authorization': self.auth_header},
                                 data=json.dumps({
-                                    'name': 'test_instance',
+                                    'name': 'test-instance',
                                     'cpus': 1,
                                     'memory': 1024,
                                     'network': ['87c15186-5f73-4947-a9fb-2183c4951efc'],
@@ -841,11 +853,12 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
             resp.get_json())
         self.assertEqual(400, resp.status_code)
 
-    def test_post_instance_invalid_network_uuid(self):
+    @mock.patch('shakenfist.artifact.Artifact.from_url')
+    def test_post_instance_invalid_network_uuid(self, mock_get_artifact):
         resp = self.client.post('/instances',
                                 headers={'Authorization': self.auth_header},
                                 data=json.dumps({
-                                    'name': 'test_instance',
+                                    'name': 'test-instance',
                                     'cpus': 1,
                                     'memory': 1024,
                                     'network': [
@@ -862,8 +875,9 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
             resp.get_json())
         self.assertEqual(400, resp.status_code)
 
+    @mock.patch('shakenfist.artifact.Artifact.from_url')
     @mock.patch('shakenfist.net.Network._db_get_attribute',
-                return_value={'value': 'created', 'update_time': 2})
+                return_value={'value': dbo.STATE_CREATED, 'update_time': 2})
     @mock.patch('shakenfist.net.Network.from_db',
                 return_value=FakeNetwork(
                     uuid='87c15186-5f73-4947-a9fb-2183c4951efc',
@@ -875,7 +889,8 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
     @mock.patch('shakenfist.db.get_lock')
     @mock.patch('shakenfist.ipmanager.IPManager.from_db')
     def test_post_instance_only_system_specifies_namespaces(
-            self, mock_ipmanager, mock_lock, mock_net, mock_net_attribute):
+            self, mock_ipmanager, mock_lock, mock_net, mock_net_attribute,
+            mock_get_artifact):
         resp = self.client.post(
             '/auth', data=json.dumps({'namespace': 'banana', 'key': 'foo'}))
         self.assertEqual(200, resp.status_code)
@@ -885,7 +900,7 @@ class ExternalApiInstanceTestCase(ExternalApiTestCase):
                                 headers={
                                     'Authorization': non_system_auth_header},
                                 data=json.dumps({
-                                    'name': 'test_instance',
+                                    'name': 'test-instance',
                                     'cpus': 1,
                                     'memory': 1024,
                                     'network': [
@@ -908,12 +923,13 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
     def setUp(self):
         super(ExternalApiNetworkTestCase, self).setUp()
 
-        class FakeConfig(SFConfigBase):
+        class FakeConfig(BaseSettings):
             NODE_NAME: str = 'seriously'
-            NODE_IP: str = '127.0.0.1'
+            NODE_EGRESS_IP: str = '127.0.0.1'
             NETWORK_NODE_IP = '127.0.0.1'
             LOG_METHOD_TRACE: int = 1
             NODE_EGRESS_NIC: str = 'eth0'
+            NODE_MESH_NIC: str = 'eth1'
 
         fake_config_network = FakeConfig()
         self.config = mock.patch('shakenfist.config.config',
@@ -925,7 +941,7 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
         self.addCleanup(self.config.stop)
 
     @mock.patch('shakenfist.net.Network._db_get_attribute',
-                return_value={'value': 'created', 'update_time': 2})
+                return_value={'value': dbo.STATE_CREATED, 'update_time': 2})
     @mock.patch('shakenfist.ipmanager.IPManager.from_db')
     @mock.patch('shakenfist.net.Network.from_db',
                 return_value=FakeNetwork(
@@ -947,15 +963,19 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
     @mock.patch('shakenfist.ipmanager.IPManager.from_db',
                 return_value=IPManager('uuid', '10.0.0.0/24'))
     @mock.patch('shakenfist.net.Network.remove_dhcp')
-    @mock.patch('shakenfist.net.Network.delete')
+    @mock.patch('shakenfist.net.Network.delete_on_network_node')
+    @mock.patch('shakenfist.net.Network.delete_on_hypervisor')
     @mock.patch('shakenfist.net.Network.state')
     @mock.patch('shakenfist.etcd.put')
+    @mock.patch('shakenfist.etcd.enqueue')
     @mock.patch('shakenfist.db.get_lock')
     def test_delete_all_networks(self,
                                  mock_db_get_lock,
+                                 mock_etcd_enqueue,
                                  mock_etcd_put,
                                  mock_network_state,
-                                 mock_delete,
+                                 mock_delete_on_hypervisor,
+                                 mock_delete_on_network_node,
                                  mock_remove_dhcp,
                                  mock_get_ipmanager,
                                  mock_network_interfaces,
@@ -981,7 +1001,7 @@ class ExternalApiNetworkTestCase(ExternalApiTestCase):
                     namespace='foo',
                     name='bob',
                     netblock='10.10.0.0/24',
-                    state='deleted'
+                    state=dbo.STATE_DELETED
                 ))
     @mock.patch('shakenfist.etcd.get_all',
                 return_value=[(None, {'uuid': '30f6da44-look-i-am-uuid'})])
